import { Injectable } from '@angular/core';
import { Diary } from '../modals/diary.modal';

@Injectable({
  providedIn: 'root'
})
export class DiaryService {
  private storageKey = 'diaries';

  constructor() {}

  async getDiaries(): Promise<Diary[]> {
    const data = localStorage.getItem(this.storageKey);
    return data ? JSON.parse(data) : [];
  }

  async addDiary(diary: Diary): Promise<void> {
    const diaries = await this.getDiaries();
    diaries.push(diary);
    localStorage.setItem(this.storageKey, JSON.stringify(diaries));
  }

  async updateDiary(updatedDiary: Diary): Promise<void> {
    const diaries = await this.getDiaries();
    const index = diaries.findIndex(d => d.id === updatedDiary.id);
    if (index !== -1) {
      diaries[index] = updatedDiary;
      localStorage.setItem(this.storageKey, JSON.stringify(diaries));
    }
  }

  async deleteDiary(id: number): Promise<void> {
    const diaries = await this.getDiaries();
    const updatedDiaries = diaries.filter(d => d.id !== id);
    localStorage.setItem(this.storageKey, JSON.stringify(updatedDiaries));
  }
}