import { Component, OnInit } from '@angular/core';
import { NavController } from '@ionic/angular';
//import { addIcons } from 'ionicons';
//import { add } from 'ionicons/icons';
import { AuthService } from '../services/auth.service';
import { Router } from '@angular/router';
import { ModalController } from '@ionic/angular';
import { EditPage } from './edit/edit.page';
import { DiaryService } from '../services/diary.service';
import { Diary } from '../modals/diary.modal';
 
@Component({
  selector: 'app-tab1',
  templateUrl: 'tab1.page.html',
  styleUrls: ['tab1.page.scss'],
  standalone: false,
})
export class Tab1Page implements OnInit{
  
  
  diaries: Diary[] = [];
  router: any;
  authService: any;

  constructor(
    private modalCtrl: ModalController,
    private diaryService: DiaryService,
    private navCtrl: NavController,
    //private router: Router
  ) {}

  async ngOnInit() {
    await this.loadDiaries();
  }
 
  async loadDiaries() {
    this.diaries = await this.diaryService.getDiaries();
    // Sort by date (newest first)
    this.diaries.sort((a, b) => {
      return new Date(b.date).getTime() - new Date(a.date).getTime();
    });
  }

  async goToEditPage(edit?:string) {
    const modal = await this.modalCtrl.create({
      component: EditPage,
      componentProps: {
        mode: 'create'
      }
    });
    
    modal.onDidDismiss().then(async (result) => {
      if (result.data?.saved) {
        await this.loadDiaries(); // Refresh the list
      }
    });
    
    await modal.present();
  }

  async viewDiary(diary: Diary) {
    const modal = await this.modalCtrl.create({
      component: EditPage,
      componentProps: {
        diary: diary,
        mode: 'edit'
      }
    });
    
    modal.onDidDismiss().then(async (result) => {
      if (result.data?.saved) {
        await this.loadDiaries(); // Refresh the list
      }
    });
    
    await modal.present();
  }

  async logout(login?:string) {
    await this.authService.logout();
    this.router.navigate(['/login']);
  }

  goMessage(message?:any){
    console.log(message),
    this.navCtrl.navigateForward(["tabs","tab1","message"],{
      queryParams:message
    })
    return
  }

    messageList:any[]=[
  {
    "id": 1,
    "date": "15",
    "weekday": "周三",
    "time": "14:30",
    "content": "今天阳光明媚，去公园散步时看到樱花开了。粉色的花瓣随风飘落，美得像一幅画。坐在长椅上读了一会儿书，感觉心情特别平静。",
    "weather": "晴",
    "mood": "😊"
  },
  {
    "id": 2,
    "date": "14",
    "weekday": "周二",
    "time": "21:15",
    "content": "项目终于告一段落，加班到很晚但很有成就感。回家的路上买了杯热奶茶犒劳自己，发现常去的那家奶茶店换了新包装，杯子上画着可爱的小兔子。",
    "weather": "多云",
    "mood": "😌"
  },
  {
    "id": 3,
    "date": "12",
    "weekday": "周日",
    "time": "09:45",
    "content": "周末尝试做了新的菜谱 - 番茄牛腩。虽然炖的时间比预期长，但结果非常美味！下午窝在沙发上看了一部老电影，窗外下着小雨，这种慵懒的周末真是太棒了。",
    "weather": "小雨",
    "mood": "🥰"
  },
  {
    "id": 4,
    "date": "18",
    "weekday": "周五",
    "time": "18:20",
    "content": "参加了公司的团队建设活动，第一次体验了攀岩项目。虽然爬到一半有些害怕，但在同事的鼓励下成功登顶，突破自我的感觉真好！",
    "weather": "阴",
    "mood": "😄"
  },
  {
    "id": 5,
    "date": "20",
    "weekday": "周六",
    "time": "15:10",
    "content": "和朋友去了新开的猫咖，有十几只不同品种的猫咪。最喜欢那只胖乎乎的橘猫，它居然在我腿上睡了一下午，治愈了连日的疲惫。",
    "weather": "晴",
    "mood": "😺"
  },
  {
    "id": 6,
    "date": "22",
    "weekday": "周一",
    "time": "08:05",
    "content": "早起晨跑时发现小区里的桂花开了，空气里都是甜甜的香气。顺手拍了张晨光中的花枝，设为手机壁纸后整天都有好心情。",
    "weather": "雾",
    "mood": "🌼"
  },
  {
    "id": 7,
    "date": "25",
    "weekday": "周四",
    "time": "19:40",
    "content": "下班路上遇到卖糖炒栗子的小摊，热乎乎的栗子捧在手里，边走边吃仿佛回到学生时代。突然想念大学的林荫道和图书馆了。",
    "weather": "微风",
    "mood": "🍂"
  },
  {
    "id": 8,
    "date": "28",
    "weekday": "周日",
    "time": "22:30",
    "content": "整理旧物时发现了高中时期的同学录，翻看那些青涩的留言和夸张的贴纸，忍不住笑出声。那些以为忘记的回忆突然都鲜活起来。",
    "weather": "晴",
    "mood": "📖"
  }
  ]; 
}
